var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'adfun.xml',
'funconstruct.xml'
];
var list_down2 = [
'install.xml',
'introduction.xml',
'ad.xml',
'adfun.xml',
'multi_thread.xml',
'library.xml',
'cppad_ipopt_nlp.xml',
'example.xml',
'preprocessor.xml',
'appendix.xml'
];
var list_down1 = [
'independent.xml',
'funconstruct.xml',
'dependent.xml',
'abort_recording.xml',
'seq_property.xml',
'funeval.xml',
'drivers.xml',
'funcheck.xml',
'optimize.xml'
];
var list_down0 = [
'fun_assign.cpp.xml'
];
var list_current0 = [
'funconstruct.xml#Syntax',
'funconstruct.xml#Purpose',
'funconstruct.xml#x',
'funconstruct.xml#y',
'funconstruct.xml#VectorAD',
'funconstruct.xml#Default Constructor',
'funconstruct.xml#Sequence Constructor',
'funconstruct.xml#Copy Constructor',
'funconstruct.xml#Assignment Operator',
'funconstruct.xml#Assignment Operator.Taylor Coefficients',
'funconstruct.xml#Assignment Operator.Sparsity Patterns',
'funconstruct.xml#Parallel Mode',
'funconstruct.xml#Example',
'funconstruct.xml#Example.Sequence Constructor',
'funconstruct.xml#Example.Default Constructor',
'funconstruct.xml#Example.Assignment Operator'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}
